import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { BatchDeleteScheduledActionAnswer, BatchDeleteScheduledActionType } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link BatchDeleteScheduledActionCommand}.
 */
export interface BatchDeleteScheduledActionCommandInput extends BatchDeleteScheduledActionType {
}
/**
 * @public
 *
 * The output of {@link BatchDeleteScheduledActionCommand}.
 */
export interface BatchDeleteScheduledActionCommandOutput extends BatchDeleteScheduledActionAnswer, __MetadataBearer {
}
declare const BatchDeleteScheduledActionCommand_base: {
    new (input: BatchDeleteScheduledActionCommandInput): import("@smithy/smithy-client").CommandImpl<BatchDeleteScheduledActionCommandInput, BatchDeleteScheduledActionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: BatchDeleteScheduledActionCommandInput): import("@smithy/smithy-client").CommandImpl<BatchDeleteScheduledActionCommandInput, BatchDeleteScheduledActionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes one or more scheduled actions for the specified Auto Scaling group.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, BatchDeleteScheduledActionCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, BatchDeleteScheduledActionCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // BatchDeleteScheduledActionType
 *   AutoScalingGroupName: "STRING_VALUE", // required
 *   ScheduledActionNames: [ // ScheduledActionNames // required
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new BatchDeleteScheduledActionCommand(input);
 * const response = await client.send(command);
 * // { // BatchDeleteScheduledActionAnswer
 * //   FailedScheduledActions: [ // FailedScheduledUpdateGroupActionRequests
 * //     { // FailedScheduledUpdateGroupActionRequest
 * //       ScheduledActionName: "STRING_VALUE", // required
 * //       ErrorCode: "STRING_VALUE",
 * //       ErrorMessage: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param BatchDeleteScheduledActionCommandInput - {@link BatchDeleteScheduledActionCommandInput}
 * @returns {@link BatchDeleteScheduledActionCommandOutput}
 * @see {@link BatchDeleteScheduledActionCommandInput} for command's `input` shape.
 * @see {@link BatchDeleteScheduledActionCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 *
 * @public
 */
export declare class BatchDeleteScheduledActionCommand extends BatchDeleteScheduledActionCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: BatchDeleteScheduledActionType;
            output: BatchDeleteScheduledActionAnswer;
        };
        sdk: {
            input: BatchDeleteScheduledActionCommandInput;
            output: BatchDeleteScheduledActionCommandOutput;
        };
    };
}
