import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DescribeAdjustmentTypesAnswer } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeAdjustmentTypesCommand}.
 */
export interface DescribeAdjustmentTypesCommandInput {
}
/**
 * @public
 *
 * The output of {@link DescribeAdjustmentTypesCommand}.
 */
export interface DescribeAdjustmentTypesCommandOutput extends DescribeAdjustmentTypesAnswer, __MetadataBearer {
}
declare const DescribeAdjustmentTypesCommand_base: {
    new (input: DescribeAdjustmentTypesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeAdjustmentTypesCommandInput, DescribeAdjustmentTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeAdjustmentTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeAdjustmentTypesCommandInput, DescribeAdjustmentTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes the available adjustment types for step scaling and simple scaling
 *             policies.</p>
 *          <p>The following adjustment types are supported:</p>
 *          <ul>
 *             <li>
 *                <p>
 *                   <code>ChangeInCapacity</code>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <code>ExactCapacity</code>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <code>PercentChangeInCapacity</code>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DescribeAdjustmentTypesCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DescribeAdjustmentTypesCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = {};
 * const command = new DescribeAdjustmentTypesCommand(input);
 * const response = await client.send(command);
 * // { // DescribeAdjustmentTypesAnswer
 * //   AdjustmentTypes: [ // AdjustmentTypes
 * //     { // AdjustmentType
 * //       AdjustmentType: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeAdjustmentTypesCommandInput - {@link DescribeAdjustmentTypesCommandInput}
 * @returns {@link DescribeAdjustmentTypesCommandOutput}
 * @see {@link DescribeAdjustmentTypesCommandInput} for command's `input` shape.
 * @see {@link DescribeAdjustmentTypesCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 *
 * @example To describe the Amazon EC2 Auto Scaling adjustment types
 * ```javascript
 * // This example describes the available adjustment types.
 * const input = { /* empty *\/ };
 * const command = new DescribeAdjustmentTypesCommand(input);
 * const response = await client.send(command);
 * /* response is
 * {
 *   AdjustmentTypes: [
 *     {
 *       AdjustmentType: "ChangeInCapacity"
 *     },
 *     {
 *       AdjustmentType: "ExactCapcity"
 *     },
 *     {
 *       AdjustmentType: "PercentChangeInCapacity"
 *     }
 *   ]
 * }
 * *\/
 * ```
 *
 * @public
 */
export declare class DescribeAdjustmentTypesCommand extends DescribeAdjustmentTypesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: {};
            output: DescribeAdjustmentTypesAnswer;
        };
        sdk: {
            input: DescribeAdjustmentTypesCommandInput;
            output: DescribeAdjustmentTypesCommandOutput;
        };
    };
}
