import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { ProcessesType } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeScalingProcessTypesCommand}.
 */
export interface DescribeScalingProcessTypesCommandInput {
}
/**
 * @public
 *
 * The output of {@link DescribeScalingProcessTypesCommand}.
 */
export interface DescribeScalingProcessTypesCommandOutput extends ProcessesType, __MetadataBearer {
}
declare const DescribeScalingProcessTypesCommand_base: {
    new (input: DescribeScalingProcessTypesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeScalingProcessTypesCommandInput, DescribeScalingProcessTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeScalingProcessTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeScalingProcessTypesCommandInput, DescribeScalingProcessTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes the scaling process types for use with the <a href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_ResumeProcesses.html">ResumeProcesses</a>
 *             and <a href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_SuspendProcesses.html">SuspendProcesses</a> APIs.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DescribeScalingProcessTypesCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DescribeScalingProcessTypesCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = {};
 * const command = new DescribeScalingProcessTypesCommand(input);
 * const response = await client.send(command);
 * // { // ProcessesType
 * //   Processes: [ // Processes
 * //     { // ProcessType
 * //       ProcessName: "STRING_VALUE", // required
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeScalingProcessTypesCommandInput - {@link DescribeScalingProcessTypesCommandInput}
 * @returns {@link DescribeScalingProcessTypesCommandOutput}
 * @see {@link DescribeScalingProcessTypesCommandInput} for command's `input` shape.
 * @see {@link DescribeScalingProcessTypesCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 *
 * @example To describe the Auto Scaling process types
 * ```javascript
 * // This example describes the Auto Scaling process types.
 * const input = { /* empty *\/ };
 * const command = new DescribeScalingProcessTypesCommand(input);
 * const response = await client.send(command);
 * /* response is
 * {
 *   Processes: [
 *     {
 *       ProcessName: "AZRebalance"
 *     },
 *     {
 *       ProcessName: "AddToLoadBalancer"
 *     },
 *     {
 *       ProcessName: "AlarmNotification"
 *     },
 *     {
 *       ProcessName: "HealthCheck"
 *     },
 *     {
 *       ProcessName: "Launch"
 *     },
 *     {
 *       ProcessName: "ReplaceUnhealthy"
 *     },
 *     {
 *       ProcessName: "ScheduledActions"
 *     },
 *     {
 *       ProcessName: "Terminate"
 *     }
 *   ]
 * }
 * *\/
 * ```
 *
 * @public
 */
export declare class DescribeScalingProcessTypesCommand extends DescribeScalingProcessTypesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: {};
            output: ProcessesType;
        };
        sdk: {
            input: DescribeScalingProcessTypesCommandInput;
            output: DescribeScalingProcessTypesCommandOutput;
        };
    };
}
